@@ -180,19 +180,38 @@ try:
 except:
     from ordereddict import OrderedDict  # from PyPI
 
-import nflgame.game as game
-import nflgame.player as player
-import nflgame.schedule as schedule
+import nflgame.game
+import nflgame.player
+import nflgame.schedule
+import nflgame.seq
 
-VERSION = "1.0.6"
+VERSION = "1.0.7"
 
-NoPlayers = player.Players(None)
+NoPlayers = nflgame.seq.GenPlayerStats(None)
 """
 NoPlayers corresponds to the identity element of a Players sequences.
 
 Namely, adding it to any other Players sequence has no effect.
 """
 
+players = nflgame.player._create_players()
+"""
+A dict of all players and meta information about each player keyed
+by GSIS ID. (The identifiers used by NFL.com GameCenter.)
+"""
+
+
+def find(name):
+    """
+    Finds a player (or players) with a name matching (case insensitive)
+    name and returns them as a list.
+    """
+    hits = []
+    for player in players.itervalues():
+        if player.name.lower() == name.lower():
+            hits.append(player)
+    return hits
+
 
 def games(year, week=None, home=None, away=None, preseason=False):
     """
@@ -200,6 +219,9 @@ def games(year, week=None, home=None, away=None, preseason=False):
     game can then be queried for player statistics and information about
     the game itself (score, winner, scoring plays, etc.).
 
+    As a special case, if the home and away teams are set to the same team,
+    then all games where that team played are returned.
+
     Note that if a game's JSON data is not cached to disk, it is retrieved
     from the NFL web site. A game's JSON data is *only* cached to disk once
     the game is over, so be careful with the number of times you call this
@@ -208,7 +230,7 @@ def games(year, week=None, home=None, away=None, preseason=False):
     eids = __search_schedule(year, week, home, away, preseason)
     if not eids:
         return None
-    return [game.Game(eid) for eid in eids]
+    return [nflgame.game.Game(eid) for eid in eids]
 
 
 def one(year, week, home, away, preseason=False):
@@ -229,7 +251,7 @@ def one(year, week, home, away, preseason=False):
     if not eids:
         return None
     assert len(eids) == 1, 'More than one game matches the given criteria.'
-    return game.Game(eids[0])
+    return nflgame.game.Game(eids[0])
 
 
 def combine(games):
@@ -239,14 +261,7 @@ def combine(games):
     This can be used, for example, to get Player objects corresponding to
     statistics across an entire week, some number of weeks or an entire season.
     """
-    players = OrderedDict()
-    for game in games:
-        for p in game.players:
-            if p.playerid not in players:
-                players[p.playerid] = p
-            else:
-                players[p.playerid] += p
-    return player.Players(players)
+    return reduce(lambda ps1, ps2: ps1 + ps2, map(lambda g: g.players, games))
 
 
 def __search_schedule(year, week=None, home=None, away=None, preseason=False):
@@ -255,7 +270,7 @@ def __search_schedule(year, week=None, home=None, away=None, preseason=False):
     given.
     """
     ids = []
-    for (y, t, w, h, a), info in schedule.games:
+    for (y, t, w, h, a), info in nflgame.schedule.games:
         if y != year:
             continue
         if week is not None:
@@ -263,10 +278,14 @@ def __search_schedule(year, week=None, home=None, away=None, preseason=False):
                 continue
             if not isinstance(week, list) and w != week:
                 continue
-        if home is not None and h != home:
-            continue
-        if away is not None and a != away:
-            continue
+        if home is not None and away is not None and home == away:
+            if h != home and a != home:
+                continue
+        else:
+            if home is not None and h != home:
+                continue
+            if away is not None and a != away:
+                continue
         if preseason and t != "PRE":
             continue
         if not preseason and t != "REG":
